@@ -1,6 +1,6 @@
 from __future__ import annotations
 import contextlib
-from typing import Any, Dict
+from typing import Any, Dict, Optional, get_args
 from enum import Enum, EnumMeta
 # Dataclass
 import inspect
@@ -210,10 +210,13 @@ class ModelMixin:
         self,
         remove_nulls: bool = False,
         convert_enums: bool = False,
-        as_values: bool = False
+        as_values: bool = False,
+        exclude: Optional[set] = None
     ) -> dict[str, Any]:
+        exclude = exclude or set()
+        exclude.add('_pgoutput')  # Always exclude _pgoutput
         if as_values:
-            return self.__collapse_as_values__(remove_nulls, convert_enums, as_values)
+            return self.__collapse_as_values__(remove_nulls, convert_enums, as_values, exclude)
         d = as_dict(self, dict_factory=dict)
         if convert_enums:
             d = self.__convert_enums__(d)
@@ -226,12 +229,21 @@ class ModelMixin:
         self,
         remove_nulls: bool = False,
         convert_enums: bool = False,
-        as_values: bool = False
+        as_values: bool = False,
+        exclude: Optional[set] = None
     ) -> dict[str, Any]:
         """Recursively converts any BaseModel instances to their primary key value."""
         out = {}
         _fields = self.columns()
         for name, field in _fields.items():
+            if name in exclude:
+                continue
+            # Skip internal or error fields
+            if name.startswith('__') or name == '__errors__':
+                continue
+            # Skip fields marked for exclusion
+            if field.metadata.get('exclude', False):
+                continue
             # datatype = field.type
             value = getattr(self, name)
             if value is None and remove_nulls:
@@ -250,13 +262,22 @@ class ModelMixin:
                     )
             # if it's a list, might contain submodels or scalars
             elif isinstance(value, list):
-                if field.origin is list and field.args:
-                    submodel_class = field.args[0]  # The type inside the list
-                    if issubclass(
-                        submodel_class, ModelMixin
-                    ) and not hasattr(submodel_class, name):
-                        out[name] = json_encoder(value)
-                        continue
+                targs = field.args
+                if len(targs) == 2 and targs[1] is type(None):
+                    # Checking if it's Optional[T]
+                    submodel_class = get_args(targs[0])
+                elif field.origin is list and field.args:
+                    submodel_class = field.args[0]
+                else:
+                    submodel_class = None
+                if field.origin is list and submodel_class and (
+                    issubclass(
+                        submodel_class,
+                        ModelMixin
+                    ) and not hasattr(submodel_class, name)
+                ):
+                    out[name] = json_encoder(value)
+                    continue
                 items_out = []
                 for item in value:
                     if isinstance(item, ModelMixin):
